<%@ Import Namespace="System" %>
<%@ Import Namespace="System.IO" %>
<%@ Import Namespace="System.Data" %>
<%@ Assembly Name="System.Xml" %>
<%@ Import Namespace="System.NewXml" %>

<script language="C#" runat=server>
public class LoadDataSetXMLDataSample	
{
	private String m_Document = "";
	private String m_Schema = "";
	private XmlDataDocument m_datadoc;
	
	public string Start(String[] args)
	{
		m_Document = args[0];
		m_Schema = args[1];
		StringWriter writer = new StringWriter();
		Console.SetOut(writer);

		try
		{
			Console.WriteLine("Creating an XmlDataDocument ...");
			m_datadoc = new XmlDataDocument();
			ParseSchema(m_Schema);
			DisplayTableStructure();

            m_datadoc.Load(m_Document);

            DisplayTables(m_datadoc.DataSet);
		}
		catch (Exception e)
		{
			Console.WriteLine ("Exception: {0}", e.ToString());
		}

		return writer.ToString();
	}

    // Loads a specified schema into the DataSet
    public void ParseSchema(String schema)
    {
        StreamReader streamreader_schema = null;

        try 
        {
            Console.WriteLine("Reading Schema file ...");
            streamreader_schema = new StreamReader(schema);
            m_datadoc.DataSet.ReadXmlSchema(streamreader_schema);
        }

        catch (Exception e)
        {
            Console.WriteLine ("Exception: {0}", e.ToString());
        }

        finally 
        {
            if (streamreader_schema != null)
                streamreader_schema.Close();
        }
    }    

	// Displays the DataSet tables structure
	private void DisplayTableStructure()
	{
		Console.WriteLine("\r\nTable structure \r\n");
		Console.WriteLine("Tables count=" + m_datadoc.DataSet.Tables.Count.ToString());
		for (int i = 0; i < m_datadoc.DataSet.Tables.Count; i++)
		{
			Console.WriteLine("\tTableName='" + m_datadoc.DataSet.Tables[i].TableName + "'.");
			Console.WriteLine("\tColumns count=" + m_datadoc.DataSet.Tables[i].Columns.Count.ToString());

			for (int j = 0; j < m_datadoc.DataSet.Tables[i].Columns.Count; j++)
			{
				Console.WriteLine("\t\tColumnName='" + m_datadoc.DataSet.Tables[i].Columns[j].ColumnName + "', type = " + m_datadoc.DataSet.Tables[i].Columns[j].DataType.ToString());
			}
		}
	}

	// Displays the contents of the DataSet tables
	private void DisplayTables(DataSet dataset)
	{
		// Navigate Dataset
		Console.WriteLine("Content of Tables ...\r\n");

		foreach(DataTable table in dataset.Tables)
		{
			Console.WriteLine("TableName = " + table.TableName);
			Console.WriteLine("Columns ...\r\n");

			foreach(DataColumn column in table.Columns)
			{
				Console.Write("{0,-22}",column.ColumnName);
			}
            Console.WriteLine("");
            Console.WriteLine("\r\nNumber of rows = {0}", table.Rows.All.Length);
			Console.WriteLine("Rows ...\r\n");

			foreach(DataRow row in table.Rows)
			{
				foreach(Object value in row.ItemArray)
				{
                    Console.Write("{0,-22}",value.ToString());
				}
				Console.WriteLine();
			}
			Console.WriteLine();
		}
	}
} 
</script>
<html>
<head>
      	<link rel="stylesheet" href="intro.css">
</head>
<body style="background-color:f6e4c6">

       	<form action="LoadDataSetXMLData.aspx" method="post" runat="server">
       	<font>Schema file: </font> 
        <a href="/quickstart/howto/samples/Xml/LoadDataSetXMLData/books.xml">books.xml</a>
       	&nbsp;&nbsp;<font>Schema file: </font> 
        <a href="/quickstart/howto/samples/Xml/LoadDataSetXMLData/books.xsd">books.xsd</a>
	<center>
		&nbsp;&nbsp;&nbsp;&nbsp;<asp:button type=submit text="Run" OnClick="SubmitBtn_Click" runat="server"/></br>
       	</form>
	</center>
	<p>

	<table align="center">
	<tr><th><span>Output from loading XML data with schema...</span></th></tr>
	<tr><th><span></span></th></tr>
	<tr><td><h4><xmp id="output" runat="server"/></h4></td></tr>
	</table>

</body>
</html>

<script language="C#" runat=server>

private void SubmitBtn_Click(Object sender, EventArgs e)
{
	String[] args = {Server.MapPath("books.xml"), Server.MapPath("books.xsd")};

	LoadDataSetXMLDataSample myLoadDataSetXMLDataSample= new LoadDataSetXMLDataSample();
	output.InnerHtml = myLoadDataSetXMLDataSample.Start(args);
}
</script>
