<%@ Import Namespace="System" %>
<%@ Import Namespace="System.IO" %>
<%@ Assembly Name="System.Xml" %>
<%@ Import Namespace="System.NewXml" %>

<script language="C#" runat=server>
public class ReadXmlStreamSample 
{
	public string Start()
	{
		StringWriter writer = new StringWriter();
		Console.SetOut(writer);

        StringReader stream;
        XmlTextReader reader = null;

        try
        {
            Console.WriteLine ("Initializing StringReader ...");

            stream = new StringReader("<?xml version='1.0'?>" +
                                      "<!-- This file represents a fragment of a book store inventory database -->" +
                                      "<bookstore>" +
                                      " <book genre=\"autobiography\" publicationdate=\"1981\" ISBN=\"1-861003-11-0\">" +
                                      "   <title>The Autobiography of Benjamin Franklin</title>" +
                                      "   <author>" +
                                      "       <first-name>Benjamin</first-name>" +
                                      "       <last-name>Franklin</last-name>" +
                                      "   </author>" +
                                      "   <price>8.99</price>" +
                                      " </book>" +
                                      " <book genre=\"novel\" publicationdate=\"1967\" ISBN=\"0-201-63361-2\">" +
                                      "   <title>The Confidence Man</title>" +
                                      "   <author>" +
                                      "       <first-name>Herman</first-name>" +
                                      "       <last-name>Melville</last-name>" +
                                      "   </author>" +
                                      "   <price>11.99</price>" +
                                      " </book>" +
                                      "  <book genre=\"philosophy\" publicationdate=\"1991\" ISBN=\"1-861001-57-6\">" +
                                      "   <title>The Gorgias</title>" +
                                      "   <author>" +
                                      "       <name>Plato</name>" +
                                      "   </author>" +
                                      "   <price>9.99</price>" +
                                      " </book>" +
                                      "</bookstore>");

            // Load the XmlTextReader from the stream
            reader = new XmlTextReader (stream);

            Console.WriteLine ("Processing ...");
            Console.WriteLine ();
            FormatXml(reader);
        }

        catch (Exception e)
        {
            Console.WriteLine ("Exception: {0}", e.ToString());
        }        

        finally 
        {
            Console.WriteLine();
            Console.WriteLine("Processing of stream complete.");
            // Finished with XmlTextReader
            if (reader != null)
                reader.Close();
        }

		return writer.ToString();
	}

    private static void FormatXml (XmlReader reader)
    {
        int PI_count=0, Doc_count=0, comment_count=0, element_count=0, attribute_count=0, text_count=0, whitespace_count=0;

        while (reader.Read())
        {
            switch (reader.NodeType)
            {
            case XmlNodeType.ProcessingInstruction:
                Format (reader, "ProcessingInstruction");
                PI_count++;
                break;
            case XmlNodeType.DocumentType:
                Format (reader, "DocumentType");
                Doc_count++;
                break;
            case XmlNodeType.Comment:
                Format (reader, "Comment");
                comment_count++;
                break;
            case XmlNodeType.Element:
                Format (reader, "Element");
                while(reader.MoveToNextAttribute())
                {
                    Format (reader, "Attribute");
                }
                element_count++;
                if (reader.HasAttributes)
                    attribute_count += reader.AttributeCount;
                break;
            case XmlNodeType.Text:
                Format (reader, "Text");
                text_count++;
                break;
            case XmlNodeType.Whitespace:
                whitespace_count++;
                break;
            }
        }

        // Display the Statistics 
        Console.WriteLine ();
        Console.WriteLine("Statistics for stream");
        Console.WriteLine ();
        Console.WriteLine("ProcessingInstruction: {0}",PI_count++);
        Console.WriteLine("DocumentType: {0}",Doc_count++);
        Console.WriteLine("Comment: {0}",comment_count++);
        Console.WriteLine("Element: {0}",element_count++);
        Console.WriteLine("Attribute: {0}",attribute_count++);
        Console.WriteLine("Text: {0}",text_count++);
        Console.WriteLine("Whitespace: {0}",whitespace_count++);
    }

    // Format the output
    private static void Format(XmlReader reader, String NodeType)
    {
        // Format the output
        Console.Write(reader.Depth + " ");
        Console.Write(reader.AttributeCount + " ");
        for (int i=0; i < reader.Depth; i++)
        { 
            Console.Write('\t');
        }

        Console.Write(NodeType + "<" + reader.Name + ">" + reader.Value);
        Console.WriteLine();
    }
} 
</script>
<html>
<head>
      	<link rel="stylesheet" href="intro.css">
</head>
<body style="background-color:f6e4c6">

       	<form action="ReadXmlStream.aspx" method="post" runat="server">
       	<font>Input file: </font> 
        <a href="/quickstart/howto/samples/Xml/ReadXmlStream/books.xml">XML representation of the stream</a>
	<center>
		&nbsp;&nbsp;&nbsp;&nbsp;<asp:button type=submit text="Run" OnClick="SubmitBtn_Click" runat="server"/></br>
       	</form>
	</center>
	<p>

	<table align="center">
	<tr><th><span >Output from reading the stream ...</span></th></tr>
	<tr><th><span></span></th></tr>
	<tr><td><h4><xmp id="output" runat="server"/></h4></td></tr>
	</table>

</body>
</html>

<script language="C#" runat=server>

private void SubmitBtn_Click(Object sender, EventArgs e)
{

	ReadXmlStreamSample Sample = new ReadXmlStreamSample();
	output.InnerHtml = Sample.Start();
}
</script>
