<%@ Import Namespace="System" %>
<%@ Import Namespace="System.IO" %>
<%@ Assembly Name="System.Xml" %>
<%@ Import Namespace="System.NewXml" %>
<%@ Import Namespace="System.NewXml.Xsl" %>

<script language="C#" runat=server>
public class XslTransformSample    
{
    private string m_Stylesheet = "";
    private string m_Document = "";
    StringWriter writer;
    
    public string Start(String[] args)
    {
        m_Document = args[0];
        m_Stylesheet = args[1];
        StringWriter writer = new StringWriter();
        Console.SetOut(writer);

        Console.WriteLine("");
        Console.WriteLine("Read XML data file, transform and format display ...");
        Console.WriteLine("");

        ReadTransform();

        Console.WriteLine("");
        Console.WriteLine("Read XML data file, transform and write ...");
        Console.WriteLine("");

        ReadTransformWrite();
        Console.WriteLine("");

        return writer.ToString();
    }

    public void ReadTransform()
    {
        try
        {
            XmlDocument xmldocument = new XmlDocument();
            xmldocument.Load (m_Document);
            DocumentNavigator navigator = new DocumentNavigator(xmldocument);

            XslTransform   xsltransform = new XslTransform();
            xsltransform.Load(m_Stylesheet);
            XmlReader reader = xsltransform.Transform(navigator, null);

            FormatXml(reader);
        }
        catch (Exception e)
        {
            Console.WriteLine ("Exception: {0}", e.ToString());
        }
    }

    public void ReadTransformWrite()
    {
        StreamReader stream = null;

        try
        {
            XmlDocument xmldocument = new XmlDocument();
            xmldocument.Load (m_Document);
            DocumentNavigator navigator = new DocumentNavigator(xmldocument);

            XslTransform xsltransform = new XslTransform();
            XmlTextWriter writer = new XmlTextWriter("transform.xml", null);

            xsltransform.Load(m_Stylesheet);
            xsltransform.Transform(navigator, null, writer);

            stream = new StreamReader ("transform.xml");
            Console.Write(stream.ReadToEnd());
        }

        catch (Exception e)
        {
            Console.WriteLine ("Exception: {0}", e.ToString());
        }

        finally
        {
            if (stream != null)
                stream.Close();
        }
    }

    private void FormatXml (XmlReader reader)
    {
        while (reader.Read())
        {
            switch (reader.NodeType)
            {
            case XmlNodeType.ProcessingInstruction:
                Format (reader, "ProcessingInstruction");
                break;
            case XmlNodeType.DocumentType:
                Format (reader, "DocumentType");
                break;
            case XmlNodeType.Document:
                Format (reader, "Document");
                break;
            case XmlNodeType.Comment:
                Format (reader, "Comment");
                break;
            case XmlNodeType.Element:
                Format (reader, "Element");
                while(reader.MoveToNextAttribute())
                {
                    Format (reader, "Attribute");
                }
                break;
            case XmlNodeType.Text:
                Boolean flag = false;
                // Do not display whitespace text nodes
                for (int i=0; i < reader.Value.Length; i++)
                {
                    if (!System.Char.IsWhiteSpace(reader.Value[i]))
                        flag = true;
                }
                if(flag)
                    Format (reader, "Text");
                break;
            }
        }
    }

    // Format the output
    private static void Format(XmlReader reader, String NodeType)
    {
        // Format the output
        for (int i=0; i < reader.Depth; i++)
        { 
            Console.Write('\t');
        }

        Console.Write(NodeType + "<" + reader.Name + ">" + reader.Value);
        Console.WriteLine();
    }
} 
</script>
<html>
<head>
          <link rel="stylesheet" href="intro.css">
</head>
<body style="background-color:f6e4c6">

           <form action="TransformXml.aspx" method="post" runat="server">
           <font>Input file: </font> 
        <a href="/quickstart/howto/samples/Xml/TransformXml/books.xml">books.xml</a>
           &nbsp;&nbsp;<font>Stylesheet: </font> 
        <a href="/quickstart/howto/samples/Xml/TransformXml/books.xsl">books.xsl</a>
    <center>
        &nbsp;&nbsp;&nbsp;&nbsp;<asp:button type=submit text="Run" OnClick="SubmitBtn_Click" runat="server"/></br>
           </form>
    </center>
    <table align="center">
    <tr><th><span>Output from the transform...</span></th></tr>
    <tr><th><span></span></th></tr>
    <tr><td><h4><xmp id="output" runat="server"/></h4></td></tr>
    </table>

</body>
</html>

<script language="C#" runat=server>

private void SubmitBtn_Click(Object sender, EventArgs e)
{
    string[] args ={Server.MapPath("books.xml"),Server.MapPath("books.xsl")};

    XslTransformSample myXslTransformSample= new XslTransformSample();
    output.InnerHtml = myXslTransformSample.Start(args);
}
</script>
