<%@ Import Namespace="System" %>
<%@ Import Namespace="System.IO" %>
<%@ Assembly Name="System.Xml" %>
<%@ Import Namespace="System.NewXml" %>

<script language="C#" runat=server>
public class ValidationReadingXMLSample
{
	private String m_Document1 = "";
	private String m_Document2 = "";
	private String m_Document3 = "";
	private String m_Document4 = "";

	private XmlTextReader m_reader = null;
	private Boolean m_success = true;

	StringWriter writer;
	
	public string Start(String[] args)
	{
		m_Document1 = args[0];
		m_Document2 = args[1];
		m_Document3 = args[2];
		m_Document4 = args[3];

		StringWriter writer = new StringWriter();
		Console.SetOut(writer);

        try
        {
            // Validate the XML file with the DTD
            Console.WriteLine();
            Console.WriteLine("Validating XML file booksDTD.xml with DTD file books.dtd ...");
            m_reader = new XmlTextReader (m_Document1);
            Validate();

            // DTD Validation failure
            m_success = true;
            Console.WriteLine();
            Console.WriteLine("Validation XML file booksDTDFail.xml with DTD file books.dtd ...");
            m_reader = new XmlTextReader (m_Document2);
            m_reader.Validation = Validation.DTD;
            Validate();

            // Validate the XML file with the schema
            m_success = true;
            Console.WriteLine();
            Console.WriteLine("Validation XML file booksSchema.xml with schema file schema.xml ...");
            m_reader = new XmlTextReader (m_Document3);
            m_reader.Validation = Validation.Schema;
            Validate();

            // Schema Validaiton failure
            m_success = true;
            Console.WriteLine();
            Console.WriteLine("Validation XML file booksSchemaFail.xml with schema file schema.xml ...");
            m_reader = new XmlTextReader (m_Document4);
            m_reader.Validation = Validation.Schema;
            Validate();
        }

        catch (Exception e)
        {
            Console.WriteLine("Exception: " + e.ToString());
        }

        finally
        {
            // Finished with XmlTextReader
            if (m_reader != null)
                m_reader.Close();
        }

		return writer.ToString();
	}	

    private void Validate()
    {
        try
        {
            // Set the validation callback
            m_reader.ValidationCallback = new ValidationDelegate(this.ValidationCallback);
            // Read XML data
            while (m_reader.Read()){}
            Console.WriteLine ("Validation finished. Validation {0}", (m_success==true ? "successful" : "failed"));
        }
        catch (XmlException e)
        {
            Console.WriteLine ("XmlException: " + e.ToString());
        }

        catch (Exception e)
        {
            Console.WriteLine ("Exception: " + e.ToString());
        }
    }

    public void ValidationCallback (int errorid, String reason)
    {
        m_success = false;
        Console.Write("\r\n\tValidation error: " + reason);
        if (m_reader.LineNumber > 0)
        {
            Console.WriteLine("Line: "+ m_reader.LineNumber + " Position: " + m_reader.LinePos);
        }
    }
} 

</script>
<html>
<head>
      	<link rel="stylesheet" href="../intro.css">
</head>
<body style="background-color:f6e4c6">

       	<form action="ValidationReadingXML.aspx" method="post" runat="server">
       	<font>Input file: </font> 
        <a href="/quickstart/howto/samples/Xml/ValidationReadingXML/books.xml">books.xml</a></br>

       	<font>XML document that validates against the books.dtd: </font> 
        <a href="/quickstart/howto/samples/Xml/ValidationReadingXML/booksDTD.xml">booksDTD.xml</a></br>

       	<font>DTD for booksDTD.xml: </font> 
        <a href="/quickstart/howto/samples/Xml/ValidationReadingXML/books.dtd">books.dtd </a></br>

       	<font>XML document that fails validation against the books.dtd: </font> 
        <a href="/quickstart/howto/samples/Xml/ValidationReadingXML/booksDTDFail.xml">booksDTDFail.xml</a></br>

       	<font>XML document that validates against the schema.xml: </font> 
        <a href="/quickstart/howto/samples/Xml/ValidationReadingXML/booksSchema.xml">booksSchema.xml</a></br>

       	<font>Schema for booksSchema.xml: </font> 
        <a href="/quickstart/howto/samples/Xml/ValidationReadingXML/schema.xml">schema.xml</a></br>

       	<font>XML document that fails validation against the schema.xml: </font> 
        <a href="/quickstart/howto/samples/Xml/ValidationReadingXML/booksSchemaFail.xml">booksSchemaFail.xml</a></br></br>

	<center>
		&nbsp;&nbsp;&nbsp;&nbsp;<asp:button type=submit text="Run" OnClick="SubmitBtn_Click" runat="server"/></br>
       	</form>
	</center>
	<p>

	<table align="center">
	<tr><th><span>Output from validation...</span></th></tr>
	<tr><th><span></span></th></tr>
	<tr><td><h4><xmp id="output" runat="server"/></h4></td></tr>
	</table>

</body>
</html>

<script language="C#" runat=server>

private void SubmitBtn_Click(Object sender, EventArgs e)
{
	String[] args = {Server.MapPath("booksDTD.xml"), Server.MapPath("booksDTDFail.xml"), Server.MapPath("booksSchema.xml"), Server.MapPath("booksSchemaFail.xml")};

	ValidationReadingXMLSample myValidationReadingXMLSample= new ValidationReadingXMLSample();
	output.InnerHtml = myValidationReadingXMLSample.Start(args);
}
</script>
